==> php82-nextcloud-28.0.6.tgz: share/nextcloud/apps/circles/l10n/es.js <==
OC.L10N.register(
    "circles",
    {
    "Teams" : "Equipos",
    "Teams' files" : "Archivos del equipo",
    "Select team to filter by" : "Selecciona el equipo por el que filtrar",
    "No teams found" : "No se encontraron equipos",
    "Please select teams to filter by" : "Por favor, seleccione los equipos por los que filtrar",
    "No files found for the selected teams" : "No se encontraron archivos para los equipos seleccionados",
    "You created the team {circle}" : "Ha creado el equipo {circle}",
    "{author} created the team {circle}" : "{author} creó el equipo {circle}",
    "You deleted {circle}" : "Has eliminado {circle}",
    "{author} deleted {circle}" : "{author} ha eliminado  {circle}",
    "You made {member} join {circle}" : "Ha hecho que {member} se una a {circle}",
    "{author} made {member} join {circle}" : "{author} ha hecho que {member} se una a {circle}",
    "You added team {member} as member to {circle}" : "Ha añadido al equipo {member} como miembro de {circle}",
    "{author} added team {member} has been added as member to {circle}" : "{author} añadió al equipo {member} como miembro de {circle}",
    "You made {member} leave {circle}" : "Ha hecho que {member} abandone {circle}",
    "{author} made {member} leave {circle}" : "{author} ha hecho que {member} abandone {circle}",
    "You removed {member} from {circle}" : "Has eliminado a {member} de {circle}",
    "You joined {circle}" : "Te has unido a {circle}",
    "{member} joined {circle}" : "{member} se ha unido a  {circle}",
    "You accepted the invitation to join {circle}" : "Has aceptado la invitación para unirte a '{circle}'",
    "{member} accepted the invitation to join {circle}" : "{member} ha aceptado la invitación a unirse a {circle}",
    "You added {member} as member to {circle}" : "Has añadido a {member} como participante de {circle}",
    "You have been added as member to {circle} by {author}" : "Has sido añadido como miembro a {circle} por {author}",
    "{member} has been added as member to {circle} by {author}" : "{author} ha añadido a {member}  como miembro de {circle}",
    "You added {external} to {circle}" : "Has añadido {external} a  {circle}",
    "{external} has been added to {circle} by {author}" : "{external} ha sido añadido a {circle} por {author}",
    "You accepted {member}'s request to join {circle}" : "Has aceptado la petición de {member} para unirse a {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Tu petición para unirse a {circle} ha sido aceptada por {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "La petición de {member} para unirse a {circle} ha sido aceptada por {author}",
    "You left {circle}" : "Has abandonado {circle}",
    "{member} left {circle}" : "{member} ha abandonado {circle}",
    "You declined the invitation to join {circle}" : "Has declinado la invitación para unirte a {circle}",
    "{member} declined an invitation to join {circle}" : "{member} ha declinado una invitación para unirse a {circle}",
    "You cancelled your request to join {circle}" : "Has cancelado tu petición para unirte a {circle}",
    "{member} cancelled a request to join {circle}" : "{member} canceló una solicitud para uniser a {circle}",
    "You have been removed from {circle} by {author}" : "Has sido eliminado de {circle} por {author}",
    "{member} has been removed from {circle} by {author}" : "{member} ha sido eliminado de {circle} por {author}",
    "You removed {external} from {circle}" : "Has eliminado a {external} de {circle}",
    "{external} has been removed from {circle} by {author}" : "{author} ha eliminado a {external} de {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "Has cancelado la invitación a {member} para unirse a {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Tu invitación a unirte a {circle} ha sido concelada por {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} ha cancelado la invitación de {member} para unirse a {circle}",
    "You dismissed {member}'s request to join {circle}" : "Has desechado la petición de {member} para unirse a {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Tu petición para unirte a {circle} ha sido desechada por {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "La petición de {member} para unirse a {circle} ha sido desechada por {author}",
    "You invited {member} to join {circle}" : "Has invitado a {member} a unirse a {circle}",
    "You have been invited to join {circle} by {author}" : "Has sido invitado a unirte a {circle} por {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} ha sido invitado a unirse a {circle} por {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Has cambiado el nivel de {member} en {circle} a %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} ha cambiado tu nivel en {circle} a %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} ha cambiado el nivel de {member} en {circle} a %1$s",
    "You sent a request to join {circle}" : "Has enviado una petición de unirte a {circle}",
    "{member} sent a request to join {circle}" : "{member} envió una petición para unirse a {circle}",
    "You are the new owner of {circle}" : "Eres el nuevo propietario de {circle}",
    "{member} is the new owner of {circle}" : "{member} es el nuevo propietario de {circle}",
    "On events happening in a <strong>team</strong> of which you are a member" : "En eventos que suceden en un <strong>equipo</strong> del cual Ud. es miembro",
    "Any important event in a <strong>team</strong> you are moderating" : "Cualquier evento importante en un <strong>equipo</strong> el cual Ud. está moderando",
    "On global events happening in any <strong>team</strong>" : "En eventos globales que suceden en cualquier <strong>equipo</strong>",
    "Shared to Circles" : "Compartido con Círculos",
    "Single" : "Único",
    "Personal" : "Personal",
    "System" : "Sistema",
    "Visible" : "Visible",
    "Open" : "Abrir",
    "Invite" : "Invitar",
    "Join request" : "Solicitud para unirse",
    "Friends" : "Amigos",
    "Password protected" : "Protegido por contraseña",
    "No Owner" : "Sin propietario",
    "Hidden" : "Oculto",
    "Backend" : "Backend",
    "Local" : "Local",
    "Root" : "Raíz",
    "Team invite" : "Invitación a equipo",
    "Federated" : "Federado",
    "Mount point" : "Punto de montaje",
    "Nextcloud Account" : "Cuenta de Nextcloud",
    "Nextcloud Group" : "Grupo de Nextcloud",
    "Email address" : "Dirección de correo electrónico",
    "Contact" : "Contacto",
    "Circle" : "Círculo",
    "Nextcloud App" : "App Nextcloud",
    "Member" : "Participante",
    "Moderator" : "Moderador",
    "Admin" : "Administrador",
    "Owner" : "Propietario",
    "%s shared »%s« with you." : "%s ha compartido «%s» contigo.",
    "%s shared »%s« with \"%s\"." : "%s compartió »%s« con \"%s\".",
    "%s on %s" : "%s en %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s compartió »%2$s« con usted.\nDebería haber recibido un correo aparte con un enlace de acceso.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s compartió »%2$s« con usted. Debería haber recibido un correo aparte con un enlace de acceso.",
    "Password to access »%1$s« shared to you by %2$s" : "Contraseña para acceder a  «%1$s» compartida contigo por %2$s",
    "Password to access »%s«" : "Contraseña para acceder »%s«",
    "It is protected with the following password:" : "Está protegido con la siguiente contraseña:",
    "%1$s via %2$s" : "%1$s vía %2$s",
    "Click the button below to open it." : "Pulsa el botón a continuación para abrirlo.",
    "Open »%s«" : "Abrir »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s compartió varios archivos con usted.\nDebería haber recibido un correo aparte con un enlace de acceso.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s compartió varios archivos con usted. Debería haber recibido un correo aparte con un enlace de acceso.",
    "Password to access files shared to you by %1$s" : "Contraseña para acceder a los archivos compartidos contigo por %1$s",
    "Password to access files" : "Contraseña para acceder a los archivos",
    "%s shared multiple files with \"%s\"." : "%s compartió múltiples archivos con \"%s\".",
    "%s shared multiple files with you." : "%s ha compartido varios archivos contigo.",
    "Boot up" : "Arrancar",
    "Nextcloud Initialization" : "Inicialización de Nextcloud",
    "Circles App Initialization" : "Inicialización de la app Circles",
    "Fresh installation status" : "Estado de la nueva instalación",
    "Building Local Database" : "Creando la Base de Datos Local",
    "Testing Basic Circle Creation" : "Prueba básica de creación de círculos",
    "Adding local users and moderators" : "Añadiendo usuarios y moderadores locales",
    "Show all teams" : "Mostrar todos los equipos",
    "Create a new team" : "Crear un equipo nuevo",
    "Files" : "Archivos",
    "This feature is not available for personal circles" : "Esta funcionalidad no está disponible para círculos personales",
    "The team is not federated" : "El equipo no está federado",
    "You cannot join this team" : "No puede unirse a este equipo",
    "This member is not a moderator" : "Este miembro no es un moderador",
    "Insufficient privileges" : "Privilegios insuficientes",
    "This member does not exist" : "Este miembro no existe",
    "This member is the owner of the team" : "Este miembro es propietario del equipo",
    "Level cannot be changed for this type of member" : "No se puede cambiar el nivel para este tipo de miembro",
    "You are already a member of this circle" : "Ya es miembro de éste círculo",
    "You have been blocked from this circle" : "Has sido bloqueado de este círculo",
    "The account is already a member of this circle" : "La cuenta ya es miembro de este círculo",
    "The account has already been invited into this circle" : "La cuenta ya ha sido invitada a este círculo",
    "%s (Team owned by %s)" : "%s (Equipo propiedad de %s)",
    "You are now a member of the Circle \"%2$s\"" : "Ahora ya eres miembro del Círculo  \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "Has sido invitado por %1$s al Círculo \"%2$s\"",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s te ha enviado una solicitud para ser miembro del Círculo \"%2$s\"",
    "Accept" : "Aceptar",
    "Refuse" : "Rechazar",
    "Leave the circle" : "Abandonar el círculo",
    "%s" : "%s",
    "Personal team" : "Equipo personal",
    "%s owned by %s" : "%s propiedad de %s",
    "You have no permission to create a new team" : "No tiene permisos para crear un equipo nuevo",
    "%s shared a file with \"%s\"." : "%s compartió un archivo con \"%s\".",
    "%s shared a file with you." : "%s compartió un archivo contigo.",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s compartió con ustedes algunos contenidos.\nYa debería haber recibido un correo electrónico separado con un enlace para acceder a él.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s compartió con ustedes algunos contenidos. Ya debería haber recibido un correo electrónico separado con un enlace para acceder a él.",
    "Password to access content shared with you by %1$s" : "Contraseña para acceder a los archivos compartidos contigo por %1$s",
    "Password to access content" : "Contraseña para acceder al contenido",
    "This item is already shared with this team" : "Este ítem ya se encuentra compartido con este equipo",
    "Bring cloud-users closer together." : "Acerca a los usuarios de nubes.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Equipos le permite a los usuarios crear sus propios grupos de personas/colegas/amigos.\nEstos grupos de personas pueden ser usados por cualquier otra app para propósitos de compartición.",
    "No files in here" : "No hay archivos aquí",
    "No entries found in this folder" : "No se han encontrado entradas en esta carpeta",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "Circles" : "Círculos",
    "Circles' files" : "Archivos de los círculos",
    "Select circles to filter by" : "Selecciona los círculos por los que filtrar",
    "No circles found" : "No se han encontrado círculos",
    "Please select circles to filter by" : "Por favor, selecciona los círculos por los que filtrar",
    "No files found for the selected circles" : "No se han encontrado archivos para los círculos seleccionados",
    "You created the circle {circle}" : "Has creado el círculo {circle}",
    "{author} created the circle {circle}" : "{author} ha creado el círculo {circle}",
    "You added circle {member} as member to {circle}" : "Añadió al círculo {member} como miembro de {circle}",
    "{author} added circle {member} has been added as member to {circle}" : "{author} añadió al círculo {member} como miembro de {circle}",
    "You removed {member} leave {circle}" : "Ha eliminado a {member} y dejó {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "En eventos que suceden en un <strong>Círculo</strong> del cual eres miembro",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Cualquier evento importante en un <strong>círculo</strong> del que seas moderador",
    "On global events happening in any <strong>Circle</strong>" : "En eventos que suceden en cualquier <strong>Círculo</strong>",
    "Join Request" : "Solicitar Unirse",
    "Password Protected" : "Protegido con contraseña",
    "Circle Invite" : "Invitar al círculo",
    "Email Address" : "Dirección de correo electrónico",
    "Circle not found" : "No se ha encontrado el círculo",
    "Circle not found " : "Círculo no encontrado",
    "This account is already a member of the circle" : "Esta cuenta ya es miembro del círculo",
    "Federated link not found" : "Enlace federado no encontrado",
    "The circle is not federated" : "El círculo no está federado",
    "You cannot join this circle" : "No puede unirse a este círculo",
    "This member is the owner of the circle" : "Este miembro es el dueño del círculo",
    "%s (Circle owned by %s)" : "%s (Círculo que pertenece a %s)",
    "Personal Circle" : "Círculo Personal",
    "You need a specify a type of circle" : "Necesitas especificar un tipo de círculo",
    "A circle with that name exists" : "Ya existe un círculo con ese nombre",
    "This member is not the owner of the circle" : "Este miebro no es el dueño del círculo",
    "This member is not an admin of the circle" : "Este miembro no es un administrador del círculo",
    "Group contains too many members" : "El grupo contiene demasiados miembros",
    "This group does not exist" : "Este grupo no existe",
    "This group is already linked to the circle" : "Este grupo ya se encuentra enlazado al círculo",
    "You cannot edit level in a personal circle" : "No puedes editar el nivel en un círculo personal",
    "Group cannot be set as owner of a circle" : "Un grupo no puede ser configurado como duelo de un círculo",
    "now" : "ahora",
    "This account does not exist" : "Esta cuenta no existe",
    "Email format is not valid" : "El formato del correo no es válido",
    "This contact is not available" : "Este contacto no está disponible",
    "You have no permission to create a new circle" : "No tienes permiso para crear un nuevo círculo",
    "This item is already shared with this circle" : "Este elemento ya ha sido compartido en este círculo",
    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Los círculos permiten a tus usuarios crear sus propios grupos de usuarios/compañeros/amigos.\nEstos grupos de usuarios (o \"círculos\") pueden ser utilizados por cualquier otra aplicación con el propósito de compartir información."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> php82-nextcloud-30.0.5.tgz: share/nextcloud/apps/circles/l10n/es.js <==
OC.L10N.register(
    "circles",
    {
    "Teams" : "Equipos",
    "You created the team {circle}" : "Ha creado el equipo {circle}",
    "{author} created the team {circle}" : "{author} creó el equipo {circle}",
    "You deleted {circle}" : "Has eliminado {circle}",
    "{author} deleted {circle}" : "{author} ha eliminado  {circle}",
    "You made {member} join {circle}" : "Ha hecho que {member} se una a {circle}",
    "{author} made {member} join {circle}" : "{author} ha hecho que {member} se una a {circle}",
    "You added team {member} as member to {circle}" : "Ha añadido al equipo {member} como miembro de {circle}",
    "You made {member} leave {circle}" : "Ha hecho que {member} abandone {circle}",
    "{author} made {member} leave {circle}" : "{author} ha hecho que {member} abandone {circle}",
    "You removed {member} from {circle}" : "Has eliminado a {member} de {circle}",
    "You joined {circle}" : "Te has unido a {circle}",
    "{member} joined {circle}" : "{member} se ha unido a  {circle}",
    "You accepted the invitation to join {circle}" : "Has aceptado la invitación para unirte a '{circle}'",
    "{member} accepted the invitation to join {circle}" : "{member} ha aceptado la invitación a unirse a {circle}",
    "You added {member} as member to {circle}" : "Has añadido a {member} como participante de {circle}",
    "You have been added as member to {circle} by {author}" : "Has sido añadido como miembro a {circle} por {author}",
    "{member} has been added as member to {circle} by {author}" : "{author} ha añadido a {member}  como miembro de {circle}",
    "You added {external} to {circle}" : "Has añadido {external} a  {circle}",
    "{external} has been added to {circle} by {author}" : "{external} ha sido añadido a {circle} por {author}",
    "You accepted {member}'s request to join {circle}" : "Has aceptado la petición de {member} para unirse a {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Tu petición para unirse a {circle} ha sido aceptada por {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "La petición de {member} para unirse a {circle} ha sido aceptada por {author}",
    "You left {circle}" : "Has abandonado {circle}",
    "{member} left {circle}" : "{member} ha abandonado {circle}",
    "You declined the invitation to join {circle}" : "Has declinado la invitación para unirte a {circle}",
    "{member} declined an invitation to join {circle}" : "{member} ha declinado una invitación para unirse a {circle}",
    "You cancelled your request to join {circle}" : "Has cancelado tu petición para unirte a {circle}",
    "{member} cancelled a request to join {circle}" : "{member} canceló una solicitud para uniser a {circle}",
    "You have been removed from {circle} by {author}" : "Has sido eliminado de {circle} por {author}",
    "{member} has been removed from {circle} by {author}" : "{member} ha sido eliminado de {circle} por {author}",
    "You removed {external} from {circle}" : "Has eliminado a {external} de {circle}",
    "{external} has been removed from {circle} by {author}" : "{author} ha eliminado a {external} de {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "Has cancelado la invitación a {member} para unirse a {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Tu invitación a unirte a {circle} ha sido concelada por {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} ha cancelado la invitación de {member} para unirse a {circle}",
    "You dismissed {member}'s request to join {circle}" : "Has desechado la petición de {member} para unirse a {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Tu petición para unirte a {circle} ha sido desechada por {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "La petición de {member} para unirse a {circle} ha sido desechada por {author}",
    "You invited {member} to join {circle}" : "Has invitado a {member} a unirse a {circle}",
    "You have been invited to join {circle} by {author}" : "Has sido invitado a unirte a {circle} por {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} ha sido invitado a unirse a {circle} por {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Has cambiado el nivel de {member} en {circle} a %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} ha cambiado tu nivel en {circle} a %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} ha cambiado el nivel de {member} en {circle} a %1$s",
    "You sent a request to join {circle}" : "Has enviado una petición de unirte a {circle}",
    "{member} sent a request to join {circle}" : "{member} envió una petición para unirse a {circle}",
    "You are the new owner of {circle}" : "Eres el nuevo propietario de {circle}",
    "{member} is the new owner of {circle}" : "{member} es el nuevo propietario de {circle}",
    "On events happening in a <strong>team</strong> of which you are a member" : "En eventos que suceden en un <strong>equipo</strong> del cual Ud. es miembro",
    "Any important event in a <strong>team</strong> you are moderating" : "Cualquier evento importante en un <strong>equipo</strong> el cual Ud. está moderando",
    "On global events happening in any <strong>team</strong>" : "En eventos globales que suceden en cualquier <strong>equipo</strong>",
    "Shared to Circles" : "Compartido con Círculos",
    "Single" : "Único",
    "Personal" : "Personal",
    "System" : "Sistema",
    "Visible" : "Visible",
    "Open" : "Abrir",
    "Invite" : "Invitar",
    "Join request" : "Solicitud para unirse",
    "Friends" : "Amigos",
    "Password protected" : "Protegido por contraseña",
    "No Owner" : "Sin propietario",
    "Hidden" : "Oculto",
    "Backend" : "Backend",
    "Local" : "Local",
    "Root" : "Raíz",
    "Team invite" : "Invitación a equipo",
    "Federated" : "Federado",
    "Mount point" : "Punto de montaje",
    "Nextcloud Account" : "Cuenta de Nextcloud",
    "Nextcloud Group" : "Grupo de Nextcloud",
    "Email address" : "Dirección de correo electrónico",
    "Contact" : "Contacto",
    "Circle" : "Círculo",
    "Nextcloud App" : "App Nextcloud",
    "Member" : "Participante",
    "Moderator" : "Moderador",
    "Admin" : "Administrador",
    "Owner" : "Propietario",
    "%s shared »%s« with you." : "%s ha compartido «%s» contigo.",
    "%s shared »%s« with \"%s\"." : "%s compartió »%s« con \"%s\".",
    "%s on %s" : "%s en %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s compartió »%2$s« con usted.\nDebería haber recibido un correo aparte con un enlace de acceso.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s compartió »%2$s« con usted. Debería haber recibido un correo aparte con un enlace de acceso.",
    "Password to access »%1$s« shared to you by %2$s" : "Contraseña para acceder a  «%1$s» compartida contigo por %2$s",
    "Password to access »%s«" : "Contraseña para acceder »%s«",
    "It is protected with the following password:" : "Está protegido con la siguiente contraseña:",
    "%1$s via %2$s" : "%1$s vía %2$s",
    "Click the button below to open it." : "Pulsa el botón a continuación para abrirlo.",
    "Open »%s«" : "Abrir »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s compartió varios archivos con usted.\nDebería haber recibido un correo aparte con un enlace de acceso.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s compartió varios archivos con usted. Debería haber recibido un correo aparte con un enlace de acceso.",
    "Password to access files shared to you by %1$s" : "Contraseña para acceder a los archivos compartidos contigo por %1$s",
    "Password to access files" : "Contraseña para acceder a los archivos",
    "%s shared multiple files with \"%s\"." : "%s compartió múltiples archivos con \"%s\".",
    "%s shared multiple files with you." : "%s ha compartido varios archivos contigo.",
    "Boot up" : "Arrancar",
    "Nextcloud Initialization" : "Inicialización de Nextcloud",
    "Circles App Initialization" : "Inicialización de la app Circles",
    "Fresh installation status" : "Estado de la nueva instalación",
    "Building Local Database" : "Creando la Base de Datos Local",
    "Testing Basic Circle Creation" : "Prueba básica de creación de círculos",
    "Adding local users and moderators" : "Añadiendo usuarios y moderadores locales",
    "Show all teams" : "Mostrar todos los equipos",
    "Create a new team" : "Crear un equipo nuevo",
    "Files" : "Archivos",
    "This feature is not available for personal circles" : "Esta funcionalidad no está disponible para círculos personales",
    "The team is not federated" : "El equipo no está federado",
    "You cannot join this team" : "No puede unirse a este equipo",
    "This member is not a moderator" : "Este miembro no es un moderador",
    "Insufficient privileges" : "Privilegios insuficientes",
    "This member does not exist" : "Este miembro no existe",
    "This member is the owner of the team" : "Este miembro es propietario del equipo",
    "Level cannot be changed for this type of member" : "No se puede cambiar el nivel para este tipo de miembro",
    "You are already a member of this circle" : "Ya es miembro de éste círculo",
    "You have been blocked from this circle" : "Has sido bloqueado de este círculo",
    "The account is already a member of this circle" : "La cuenta ya es miembro de este círculo",
    "The account has already been invited into this circle" : "La cuenta ya ha sido invitada a este círculo",
    "%s (Team owned by %s)" : "%s (Equipo propiedad de %s)",
    "Accept" : "Aceptar",
    "Refuse" : "Rechazar",
    "%s" : "%s",
    "Personal team" : "Equipo personal",
    "%s owned by %s" : "%s propiedad de %s",
    "You have no permission to create a new team" : "No tiene permisos para crear un equipo nuevo",
    "%s shared a file with \"%s\"." : "%s compartió un archivo con \"%s\".",
    "%s shared a file with you." : "%s compartió un archivo contigo.",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s compartió con ustedes algunos contenidos.\nYa debería haber recibido un correo electrónico separado con un enlace para acceder a él.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s compartió con ustedes algunos contenidos. Ya debería haber recibido un correo electrónico separado con un enlace para acceder a él.",
    "Password to access content shared with you by %1$s" : "Contraseña para acceder a los archivos compartidos contigo por %1$s",
    "Password to access content" : "Contraseña para acceder al contenido",
    "This item is already shared with this team" : "Este ítem ya se encuentra compartido con este equipo",
    "Bring cloud-users closer together." : "Acerca a los usuarios de nubes.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Equipos le permite a los usuarios crear sus propios grupos de personas/colegas/amigos.\nEstos grupos de personas pueden ser usados por cualquier otra app para propósitos de compartición.",
    "No files in here" : "No hay archivos aquí",
    "No entries found in this folder" : "No se han encontrado entradas en esta carpeta",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "Circles" : "Círculos",
    "Circles' files" : "Archivos de los círculos",
    "Select circles to filter by" : "Selecciona los círculos por los que filtrar",
    "No circles found" : "No se han encontrado círculos",
    "Please select circles to filter by" : "Por favor, selecciona los círculos por los que filtrar",
    "No files found for the selected circles" : "No se han encontrado archivos para los círculos seleccionados",
    "You created the circle {circle}" : "Has creado el círculo {circle}",
    "{author} created the circle {circle}" : "{author} ha creado el círculo {circle}",
    "You added circle {member} as member to {circle}" : "Añadió al círculo {member} como miembro de {circle}",
    "{author} added circle {member} has been added as member to {circle}" : "{author} añadió al círculo {member} como miembro de {circle}",
    "You removed {member} leave {circle}" : "Ha eliminado a {member} y dejó {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "En eventos que suceden en un <strong>Círculo</strong> del cual eres miembro",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Cualquier evento importante en un <strong>círculo</strong> del que seas moderador",
    "On global events happening in any <strong>Circle</strong>" : "En eventos que suceden en cualquier <strong>Círculo</strong>",
    "Join Request" : "Solicitar Unirse",
    "Password Protected" : "Protegido con contraseña",
    "Circle Invite" : "Invitar al círculo",
    "Email Address" : "Dirección de correo electrónico",
    "Circle not found" : "No se ha encontrado el círculo",
    "Circle not found " : "Círculo no encontrado",
    "This account is already a member of the circle" : "Esta cuenta ya es miembro del círculo",
    "Federated link not found" : "Enlace federado no encontrado",
    "The circle is not federated" : "El círculo no está federado",
    "You cannot join this circle" : "No puede unirse a este círculo",
    "This member is the owner of the circle" : "Este miembro es el dueño del círculo",
    "%s (Circle owned by %s)" : "%s (Círculo que pertenece a %s)",
    "You are now a member of the Circle \"%2$s\"" : "Ahora ya eres miembro del Círculo  \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "Has sido invitado por %1$s al Círculo \"%2$s\"",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s te ha enviado una solicitud para ser miembro del Círculo \"%2$s\"",
    "Leave the circle" : "Abandonar el círculo",
    "Personal Circle" : "Círculo Personal",
    "You need a specify a type of circle" : "Necesitas especificar un tipo de círculo",
    "A circle with that name exists" : "Ya existe un círculo con ese nombre",
    "This member is not the owner of the circle" : "Este miebro no es el dueño del círculo",
    "This member is not an admin of the circle" : "Este miembro no es un administrador del círculo",
    "Group contains too many members" : "El grupo contiene demasiados miembros",
    "This group does not exist" : "Este grupo no existe",
    "This group is already linked to the circle" : "Este grupo ya se encuentra enlazado al círculo",
    "You cannot edit level in a personal circle" : "No puedes editar el nivel en un círculo personal",
    "Group cannot be set as owner of a circle" : "Un grupo no puede ser configurado como duelo de un círculo",
    "now" : "ahora",
    "This account does not exist" : "Esta cuenta no existe",
    "Email format is not valid" : "El formato del correo no es válido",
    "This contact is not available" : "Este contacto no está disponible",
    "You have no permission to create a new circle" : "No tienes permiso para crear un nuevo círculo",
    "This item is already shared with this circle" : "Este elemento ya ha sido compartido en este círculo",
    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Los círculos permiten a tus usuarios crear sus propios grupos de usuarios/compañeros/amigos.\nEstos grupos de usuarios (o \"círculos\") pueden ser utilizados por cualquier otra aplicación con el propósito de compartir información.",
    "Teams' files" : "Archivos del equipo",
    "Select team to filter by" : "Selecciona el equipo por el que filtrar",
    "No teams found" : "No se encontraron equipos",
    "Please select teams to filter by" : "Por favor, seleccione los equipos por los que filtrar",
    "No files found for the selected teams" : "No se encontraron archivos para los equipos seleccionados",
    "{author} added team {member} has been added as member to {circle}" : "{author} añadió al equipo {member} como miembro de {circle}"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
